dot-build_smartspeed_df: Build a SmartSpeed test data frame

.build_smartspeed_dfR Documentation

Build a SmartSpeed test data frame

Description

Internal helper to convert a list of SmartSpeed summary records into a tidy data.frame. Nested scalar fields are flattened into columns, and array fields are preserved in a JSON string column.

Usage

.build_smartspeed_df(records)

Arguments

records

A list of SmartSpeed summary records from the API.

Value

A data.frame with one row per SmartSpeed summary record. Internal function (not designed to be used directly by end users)


valdr documentation built on April 22, 2026, 9:08 a.m.