dot-extract_nested: Safely extract a nested scalar field from a list of lists

.extract_nestedR Documentation

Safely extract a nested scalar field from a list of lists

Description

Internal helper function used to safely extract a nested scalar value from each record using a field path. If any level in the path is NULL, returns "".

Usage

.extract_nested(x, path)

Arguments

x

A list of lists (records), coming from parsed JSON API responses.

path

A character vector describing the nested path to extract.

Value

A vector containing the extracted values, with NULLs replaced by "". Internal function (not designed to be used directly by end users)


valdr documentation built on April 22, 2026, 9:08 a.m.