dot-extract_nested_json: Safely extract a nested object or array as JSON from a list...

.extract_nested_jsonR Documentation

Safely extract a nested object or array as JSON from a list of lists

Description

Internal helper function used to safely extract a nested object or array from each record using a field path, and preserve it as a JSON string. If any level in the path is NULL, returns "".

Usage

.extract_nested_json(x, path)

Arguments

x

A list of lists (records), coming from parsed JSON API responses.

path

A character vector describing the nested path to extract.

Value

A character vector containing JSON strings, with NULLs replaced by "". Internal function (not designed to be used directly by end users)


valdr documentation built on April 22, 2026, 9:08 a.m.