| .safe_extract_first | R Documentation |
Internal helper function used to extract the first non-empty value
from a list of fields, in order, from a list of records.
If all fields are NULL or empty strings, returns "".
.safe_extract_first(x, fields)
x |
A list of lists (records), coming from parsed JSON API responses. |
fields |
A character vector naming the candidate fields to check in order. |
A character vector containing the extracted values, with NULLs replaced by "".
Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.