dot-safe_value: Safely extract a single value

.safe_valueR Documentation

Safely extract a single value

Description

Internal helper function used to safely retrieve a single value from an object. If the value is NULL, it is replaced with an empty string ("").

Usage

.safe_value(x)

Arguments

x

A single value, possibly NULL.

Value

The original value, or "" if NULL. Internal function (not designed to be used directly by end users)


valdr documentation built on April 22, 2026, 9:08 a.m.

Related to dot-safe_value in valdr...