| .validate_single_guid | R Documentation |
Internal helper to validate that exactly one non-empty, non-NA, string-based GUID has been supplied.
.validate_single_guid(..., arg_name = "`test_id`")
... |
One or more values for the test ID. |
arg_name |
Optional string for the argument name to use in error messages. |
A single validated test ID string. Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.