get_access_token: Get or refresh VALD access token

View source: R/auth.R

get_access_tokenR Documentation

Get or refresh VALD access token

Description

Retrieves a cached access token from disk if valid, otherwise fetches a new one.

Usage

get_access_token(config = NULL, verbose = TRUE)

Arguments

config

Configuration object. If NULL, uses internal config set by set_credentials().

verbose

Whether to print a message when refreshing the token.

Value

(Invisibly) a character vector of length 1 containing the bearer token used for authenticating API requests. Internal function (not designed to be used directly by end users)


valdr documentation built on April 22, 2026, 9:08 a.m.