View source: R/forcedecks_result_definitions.R
| get_forcedecks_result_definitions | R Documentation |
Retrieves all available result definitions from the ForceDecks API.
get_forcedecks_result_definitions()
A data frame where each row corresponds to a ForceDecks result definition retrieved from the API. Returned invisibly. Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.