| get_forcedecks_result_definitions_only | R Documentation |
Wrapper around get_forcedecks_result_definitions() to refresh result definitions.
Typically called infrequently unless definitions are known to have changed.
get_forcedecks_result_definitions_only()
A data frame where each row corresponds to a ForceDecks result definition retrieved from the API. Returned invisibly.
## Not run:
# Fetch result definitions
results <- get_forcedecks_result_definitions_only()
View(results)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.