Learn R Programming

valdr (version 2.2.0)

get_forcedecks_tests_trials: Run a standard session to get new ForceDecks tests and trials only

Description

Use this when profiles and result definitions have already been downloaded previously.

Usage

get_forcedecks_tests_trials(start_date = NULL, include_attributes = FALSE)

Value

A named list with data frames: tests and trials. If include_attributes = TRUE, the list also contains test_attributes.

Arguments

start_date

In ISO 8601 UTC format (e.g., "2025-06-25T00:00:00Z") indicating the start of the test retrieval window.

include_attributes

Logical; if TRUE, the returned list will include an additional data frame test_attributes containing a long-format mapping of test attributes. Defaults to FALSE.

Examples

Run this code
if (FALSE) {
# Fetch tests and trials only
session <- get_forcedecks_tests_trials()
View(session$tests)
View(session$trials)

# Fetch tests, trials, and test attributes mapping
session2 <- get_forcedecks_tests_trials(include_attributes = TRUE)
View(session2$test_attributes)
}

Run the code above in your browser using DataLab