get_forceframe_data: Get ForceFrame test data

View source: R/session.R

get_forceframe_dataR Documentation

Get ForceFrame test data

Description

Wrapper around get_forceframe_tests() that also calls get_profiles() to ensure profile data is available before retrieving ForceFrame test data. Intended for use when you want to fetch Profiles information as well as ForceFrame tests from the API.

Usage

get_forceframe_data(start_date = NULL, profile_id = NULL)

Arguments

start_date

(Optional) A UTC ISO 8601 datetime string (e.g. "2025-06-25T00:00:00Z") used to filter results by modification time. Input as a string.

profile_id

(Optional) A specific profile ID to filter results for a single athlete. Input as a string.

Value

A data frame containing Profiles information and a data frame containing ForceFrame test data.

Examples

## Not run: 
# Fetch all recent ForceFrame tests along with Profiles information
tests <- get_forceframe_data()
View(tests)

# Fetch ForceFrame tests for a specific profile
get_forceframe_data(profile_id = "abc123")

## End(Not run)

valdr documentation built on April 22, 2026, 9:08 a.m.