get_forceframe_reps_by_id: Get ForceFrame repetitions by test ID

View source: R/forceframe_reps_by_id.R

get_forceframe_reps_by_idR Documentation

Get ForceFrame repetitions by test ID

Description

Calls the ForceFrame API endpoint ⁠/tests/{testId}/repetitions⁠ to retrieve repetition records for a single test.

Usage

get_forceframe_reps_by_id(...)

Arguments

...

The GUID of the ForceFrame test. Input as a string.

Value

A data frame containing repetition details, or an empty data frame if none are found. Internal function (not designed to be used directly by end users)


valdr documentation built on April 22, 2026, 9:08 a.m.