get_nordbord_test_by_id: Get a single NordBord test by ID

View source: R/session.R

get_nordbord_test_by_idR Documentation

Get a single NordBord test by ID

Description

Wrapper around get_nordbord_tests_by_id() to retrieve a specific NordBord test. Intended for use when you want to fetch a single NordBord test record.

Usage

get_nordbord_test_by_id(test_id)

Arguments

test_id

(Required) The unique test ID for the NordBord test you want to retrieve.

Value

A data frame with one row corresponding to the requested NordBord test. Returned invisibly.

Examples

## Not run: 
# Fetch a NordBord test by ID
test <- get_nordbord_test_by_id("abcd1234-ab12-cd34-ef56-abcdef123456")
View(test)

## End(Not run)

valdr documentation built on April 22, 2026, 9:08 a.m.