get_nordbord_tests_by_id: Get a single NordBord test by ID

View source: R/nordbord_tests_by_id.R

get_nordbord_tests_by_idR Documentation

Get a single NordBord test by ID

Description

Calls the NordBord API endpoint ⁠/tests/{testId}⁠ to retrieve one test record.

Usage

get_nordbord_tests_by_id(...)

Arguments

...

The GUID of the NordBord test. Input as a string.

Value

A data frame containing the test details, or an empty data frame if not found. Internal function (not designed to be used directly by end users)


valdr documentation built on April 22, 2026, 9:08 a.m.