get_smartspeed_data: Get SmartSpeed test data

View source: R/session.R

get_smartspeed_dataR Documentation

Get SmartSpeed test data

Description

Wrapper around get_smartspeed_tests() that also calls get_profiles() to ensure profile data is available before retrieving SmartSpeed test data. Intended for use when you want to fetch Profiles information as well as SmartSpeed tests from the API.

Usage

get_smartspeed_data(start_date = NULL)

Arguments

start_date

(Optional) A UTC ISO 8601 datetime string (e.g. "2025-06-25T00:00:00Z") used to filter results by modification time. Input as a string.

Value

A named list containing Profiles information and SmartSpeed test data.

Examples

## Not run: 
# Fetch all recent SmartSpeed tests along with Profiles information
data <- get_smartspeed_data()
View(data$profiles)
View(data$tests)

## End(Not run)

valdr documentation built on April 22, 2026, 9:08 a.m.