get_smartspeed_tests: Get SmartSpeed tests

View source: R/smartspeed_tests.R

get_smartspeed_testsR Documentation

Get SmartSpeed tests

Description

Retrieves SmartSpeed test summary data modified since a given start date.

Usage

get_smartspeed_tests(start_date = NULL)

Arguments

start_date

Optional ISO 8601 UTC date string (e.g. "2025-06-25T00:00:00Z").

Value

A data frame containing SmartSpeed test summaries. If no tests are found, returns an empty data frame. Returned invisibly. Internal function (not designed to be used directly by end users)


valdr documentation built on April 22, 2026, 9:08 a.m.