get_start_date: Retrieve the start date from config

View source: R/config.R

get_start_dateR Documentation

Retrieve the start date from config

Description

Returns the saved start date string from the config file.

Usage

get_start_date()

Value

A character scalar containing the start date string in ISO 8601 format previously saved to configuration.


valdr documentation built on April 22, 2026, 9:08 a.m.

Related to get_start_date in valdr...