| is_token_valid | R Documentation |
Check if JWT access token is expired
is_token_valid(token)
token |
A JWT access token |
A logical scalar (TRUE or FALSE) indicating whether the provided JWT access token is still valid based on its expiry timestamp. Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.