| authenticate | R Documentation |
Ensures a valid access token is available based on stored credentials. Also validates required tenant ID and token presence for subsequent function calls.
authenticate()
A character vector of length 1 (a single string) representing a valid access token. Returned invisibly and used internally for authentication. Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.