| .build_smartspeed_df | R Documentation |
Internal helper to convert a list of SmartSpeed summary records into a tidy data.frame. Nested scalar fields are flattened into columns, and array fields are preserved in a JSON string column.
.build_smartspeed_df(records)
records |
A list of SmartSpeed summary records from the API. |
A data.frame with one row per SmartSpeed summary record. Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.