| .extract_nested | R Documentation |
Internal helper function used to safely extract a nested scalar value
from each record using a field path.
If any level in the path is NULL, returns "".
.extract_nested(x, path)
x |
A list of lists (records), coming from parsed JSON API responses. |
path |
A character vector describing the nested path to extract. |
A vector containing the extracted values, with NULLs replaced by "".
Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.