| .extract_nested_json | R Documentation |
Internal helper function used to safely extract a nested object or array
from each record using a field path, and preserve it as a JSON string.
If any level in the path is NULL, returns "".
.extract_nested_json(x, path)
x |
A list of lists (records), coming from parsed JSON API responses. |
path |
A character vector describing the nested path to extract. |
A character vector containing JSON strings, with NULLs replaced by "".
Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.