| .safe_extract | R Documentation |
Internal helper function used to extract a specified field from a list of records.
If a field value is NULL, it is replaced with an empty string ("").
.safe_extract(x, field)
x |
A list of lists (records), coming from parsed JSON API responses. |
field |
A character string naming the field to extract from each record. |
A character vector containing the extracted values, with NULLs replaced by "".
Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.