| .safe_value | R Documentation |
Internal helper function used to safely retrieve a single value from an object.
If the value is NULL, it is replaced with an empty string ("").
.safe_value(x)
x |
A single value, possibly |
The original value, or "" if NULL.
Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.