| get_access_token | R Documentation |
Retrieves a cached access token from disk if valid, otherwise fetches a new one.
get_access_token(config = NULL, verbose = TRUE)
config |
Configuration object. If NULL, uses internal config set by |
verbose |
Whether to print a message when refreshing the token. |
(Invisibly) a character vector of length 1 containing the bearer token used for authenticating API requests. Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.