View source: R/forcedecks_tests.R
| get_forcedecks_tests | R Documentation |
Retrieves ForceDecks test data with optional filtering by start date and profile ID.
get_forcedecks_tests(
start_date = NULL,
profile_id = NULL,
include_attributes = FALSE
)
start_date |
Optional ISO 8601 UTC date string (e.g., "2025-06-25T00:00:00Z"). |
profile_id |
Optional Profile ID to filter results. |
include_attributes |
Logical; if FALSE (default), returns only the tests
data frame. If TRUE, returns a named list with components |
If include_attributes = FALSE, a data frame containing
ForceDecks test results matching the optional filters. If no tests are
found, returns an empty data frame.
If include_attributes = TRUE, a list with elements tests
and attributes. Returned invisibly.
Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.