View source: R/forceframe_reps_by_id.R
| get_forceframe_reps_by_id | R Documentation |
Calls the ForceFrame API endpoint /tests/{testId}/repetitions to retrieve
repetition records for a single test.
get_forceframe_reps_by_id(...)
... |
The GUID of the ForceFrame test. Input as a string. |
A data frame containing repetition details, or an empty data frame if none are found. Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.