| get_forceframe_test_by_id | R Documentation |
Wrapper around get_forceframe_tests_by_id() to retrieve a specific ForceFrame test.
Intended for use when you want to fetch a single ForceFrame test record.
get_forceframe_test_by_id(test_id)
test_id |
(Required) The unique test ID for the ForceFrame test you want to retrieve. |
A data frame with one row corresponding to the requested ForceFrame test. Returned invisibly.
## Not run:
# Fetch a ForceFrame test by ID
test <- get_forceframe_test_by_id("abcd1234-ab12-cd34-ef56-abcdef123456")
View(test)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.