View source: R/forceframe_tests_by_id.R
| get_forceframe_tests_by_id | R Documentation |
Calls the ForceFrame API endpoint /tests/{testId} to retrieve one test record.
get_forceframe_tests_by_id(...)
... |
The GUID of the ForceFrame test. Input as a string. |
A data frame containing the test details, or an empty data frame if not found. Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.