| get_nordbord_data | R Documentation |
Wrapper around get_nordbord_tests() that also calls get_profiles()
to ensure profile data is available before retrieving NordBord test data.
Intended for use when you want to fetch Profiles information as well as NordBord tests from the API.
get_nordbord_data(start_date = NULL, profile_id = NULL)
start_date |
(Optional) A UTC ISO 8601 datetime string (e.g. "2025-06-25T00:00:00Z") used to filter results by modification time. Input as a string. |
profile_id |
(Optional) A specific profile ID to filter results for a single athlete. Input as a string. |
A data frame containing Profiles information and a data frame containing NordBord test data.
## Not run:
# Fetch all recent NordBord tests along with Profiles information
tests <- get_nordbord_data()
View(tests)
# Fetch NordBord tests for a specific profile
get_nordbord_data(profile_id = "abcd1234-ab12-cd34-ef56-abcdef123456")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.