| get_profiles_groups_categories_mapping | R Documentation |
Wrapper around get_profiles_groups_categories() to retrieve
the long-format mapping of profiles to their groups and categories.
get_profiles_groups_categories_mapping()
Intended for use when you want a relational view of profile metadata
rather than the one-row-per-profile structure returned by get_profiles().
A data frame with one row per profile–group–category combination, containing the columns:
profileId
categoryId
categoryName
groupId
groupName
Returned invisibly.
## Not run:
# Fetch profile–group–category mappings for the current tenant
mappings <- get_profiles_groups_categories_mapping()
head(mappings)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.