View source: R/smartspeed_tests.R
| get_smartspeed_tests | R Documentation |
Retrieves SmartSpeed test summary data modified since a given start date.
get_smartspeed_tests(start_date = NULL)
start_date |
Optional ISO 8601 UTC date string (e.g. "2025-06-25T00:00:00Z"). |
A data frame containing SmartSpeed test summaries. If no tests are found, returns an empty data frame. Returned invisibly. Internal function (not designed to be used directly by end users)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.